@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# $Id: pytwitter.py 130 2008-11-10 19:17:21Z nsheridan@EVIL.IE $
+# $Id: pytwitter.py 175 2009-05-10 00:29:23Z nsheridan@EVIL.IE $
 #
 
 """ Twitter api class.
@@ -23,7 +23,6 @@ Unless an exception is raised, full output is returned in the requested format
 Default: xml. Optional: json.
 """
 
-import exceptions
 import re
 import urllib
 import urllib2
@@ -32,7 +31,7 @@ __author__ = 'nsheridan@gmail.com (Niall Sheridan)'
 __license__ = 'Python'
 __copyright__ = 'Copyright 2008, Niall Sheridan'
 
-class TwitterError(exceptions.Exception):
+class TwitterError(Exception):
   """ TwitterError exception
   Raised when the server returns something unexpected
   """
@@ -75,13 +74,27 @@ class pytwitter:
       else:
         # Everything else.
         _method = _method.replace('_', '/', 1)
+      # Some methods are POST only. Default to sending a GET.
+      use_post = False
+      post_only_methods = ['statuses/update', 'statuses/delete',
+          'account/endsession', 'friendships/destroy', 'friendships/create',
+          'direct_messages/destroy', 'direct_messages/new',
+          'account/update_delivery_service', 'account/update_profile_colors',
+          'account/update_profile_image', 'favorites/create',
+          'account/update_profile_background_image', 'account/update_profile',
+          'notifications/follow', 'notifications/leave', 'blocks/create',
+          'blocks/destroy', 'favorites/destroy']
+      if _method in post_only_methods:
+        use_post = True
       url = '%s/%s.%s' % (_self.url, _method, _self.format)
-      params = urllib.urlencode(eval(str(params)))
-      resp = _self._send_data(url, params)
+      for key in params.keys():
+        params[key] = str(params[key])
+      params = urllib.urlencode(params)
+      resp = _self._send_data(url, params, use_post)
       return resp
     return method
 
-  def _send_data(self, url, data):
+  def _send_data(self, url, data, use_post=False):
     """ Authenticates with the server
     Sends the request and returns the xml or json response
     Raises TwitterError exception on urllib2.UrlError
@@ -91,7 +104,11 @@ class pytwitter:
       pwdmanager.add_password(
           None, self.url, self.username, self.password)
       opener = urllib2.build_opener(urllib2.HTTPBasicAuthHandler(pwdmanager))
-      req = urllib2.Request(url, data)
+      if use_post:
+        req = urllib2.Request(url, data)
+      else:
+        url = '%s?%s' % (url, data)
+        req = urllib2.Request(url)
       resp = opener.open(req).read()
       try:
         return resp
